@@ -743,7 +743,7 @@ def _do_check_install_state(ctx, config, module, all_modules, no_dangling_check)
                 problem_missing.add(module)
         if problem_missing:
             for missing in sorted(problem_missing):
-                click.secho("Missing: {missing}", fg="red")
+                click.secho(f"Missing: {missing}", fg="red")
             abort("Missing after installation")
 
 
@@ -1060,7 +1060,10 @@ def robotest(
     if odoo_modules:
 
         def not_installed(module):
-            return DBModules.get_meta_data(module)["state"] == "uninstalled"
+            data = DBModules.get_meta_data(module)
+            if not data:
+                abort(f"Could not get state for {module}")
+            return data["state"] == "uninstalled"
 
         modules_to_install = list(filter(not_installed, odoo_modules))
         if modules_to_install:
