@@ -1060,10 +1060,14 @@ class Module(object):
         cwd = Path(os.getcwd())
         if str(path).startswith("/"):
             try:
-                path = path.relative_to(cwd)
-            except ValueError:
                 path = path.relative_to(customs_dir())
-                os.chdir(customs_dir())  # reset later; required that parents works
+                os.chdir(customs_dir())
+            except:
+                try:
+                    path = path.relative_to(cwd)
+                except ValueError:
+                    path = path.relative_to(customs_dir())
+                    os.chdir(customs_dir())  # reset later; required that parents works
         p = path if path.is_dir() else path.parent
 
         for p in [p] + list(p.parents):
@@ -1087,7 +1091,8 @@ class Module(object):
     def manifest_dict(self):
         if not self._manifest_dict:
             try:
-                content = self.manifest_path.read_text()
+                path = customs_dir() / self.manifest_path
+                content = path.read_text()
                 content = "\n".join(
                     filter(
                         lambda x: not x.strip().startswith("#"), content.splitlines()
